## Hypothesis Creation

### Team Composition

To address this question we have assembled the following team:

{team_description}

### Building Hypotheses and Tests

Based on the team composition, along with all identified known and unknown facts, please begin by creating one to three hypotheses that could be tested to address the original request.

For each hypothesis, consider the following:

- Can this hypothesis be tested using the finite set of capabilities available to our team members? If not, this is not a valid hypothesis. 
- Is this hypothesis _relatively_ simple? We want to avoid overly complex hypotheses that would require a lot of time and effort to test.

With this in mind, create simple, actionable hypotheses that can be tested using the capabilities of the team members. For each hypothesis, please provide the following:

1. A description of the hypothesis.
2. One to three tests that could be performed to verify or disprove the hypothesis. The tests should be specific and actionable, and should include the following:
   - Friendly name for the test.
   - A description of the test
   
Note that not all team members are necessarily required for each test; use your judgment to determine which team members are needed.

### IMPORTANT NOTE

- Again, you and your team cannot interact with the outside world, so you cannot run any tests that require external data or physical tools.

